[Zope3-checkins] CVS: Zope3/src/zope/app/workflow - meta.zcml:1.7 metadirectives.py:1.4
Stephan Richter
srichter@cosmos.phy.tufts.edu
Sat, 2 Aug 2003 12:36:59 -0400
Update of /cvs-repository/Zope3/src/zope/app/workflow
In directory cvs.zope.org:/tmp/cvs-serv29742/workflow
Modified Files:
meta.zcml metadirectives.py
Log Message:
redo philiKON's changes to this module.
=== Zope3/src/zope/app/workflow/meta.zcml 1.6 => 1.7 ===
--- Zope3/src/zope/app/workflow/meta.zcml:1.6 Sat Aug 2 05:11:29 2003
+++ Zope3/src/zope/app/workflow/meta.zcml Sat Aug 2 12:36:54 2003
@@ -5,13 +5,13 @@
<meta:directive
namespace="http://namespaces.zope.org/workflow"
name="importHandler"
- schema=".metadirectives.IImportHandlerDirective"
+ schema=".metadirectives.IHandlerDirective"
handler=".metaconfigure.importHandlerDirective" />
<meta:directive
namespace="http://namespaces.zope.org/workflow"
name="exportHandler"
- schema=".metadirectives.IExportHandlerDirective"
+ schema=".metadirectives.IHandlerDirective"
handler=".metaconfigure.exportHandlerDirective" />
</configure>
=== Zope3/src/zope/app/workflow/metadirectives.py 1.3 => 1.4 ===
--- Zope3/src/zope/app/workflow/metadirectives.py:1.3 Sat Aug 2 05:11:29 2003
+++ Zope3/src/zope/app/workflow/metadirectives.py Sat Aug 2 12:36:54 2003
@@ -18,14 +18,15 @@
from zope.configuration.fields import GlobalObject
from zope.interface import Interface
-class IImportHandlerDirective(Interface):
- """Register an Import Handler, that is able to load a XML Representation
- of a ProcessDefinition and create a persistent Instance for it."""
+class IHandlerDirective(Interface):
+ """Register an Import/Export Handler, that is able to load/save a XML
+ Representation of a ProcessDefinition and create a persistent Instance for
+ it."""
interface = GlobalObject(
title=u"Interface",
description=u"The interface of the process definition this "\
- u"handler can load.",
+ u"handler can handle (both for either import or export).",
required=True)
factory = GlobalObject(
@@ -33,21 +34,3 @@
description=u"The factory for the instance that implements the "\
u"handler.",
required=True)
-
-
-class IExportHandlerDirective(Interface):
- """Register an Export Handler, that is able to save a XML Representation
- of a ProcessDefinition from a given object."""
-
- interface = GlobalObject(
- title=u"Interface",
- description=u"The interface of the process definition this "\
- u"handler can save.",
- required=True)
-
- factory = GlobalObject(
- title=u"Factory",
- description=u"The factory for the instance that implements the "\
- u"handler.",
- required=True)
-